const path = require('path');
const fs = require('fs');

const request = require('request');
const mkdirp = require('mkdirp');
const { exec, cd } = require('shelljs')
const _ = require('lodash');
const homedir = require('homedir');

const args = require('minimist')(process.argv.slice(2));

if (args._.length < 1) {
    console.log('Useage: reel <username> [directory]');
    process.exit(1);
}

const user = args._[0];
const dirName = args._[1] || 'gh-backup';

const options = {
    url: `https://api.github.com/users/${user}/repos`,
    qs: {
        per_page: 100,
    },
    headers: {
        'User-Agent': 'request',
    }
};

const dir = path.resolve(homedir(), dirName);

console.log(`Backing up GitHub user ${user} to ${dir}`);

mkdirp(dir);

request(options, function (error, response, body) {
    if (error || response.statusCode !== 200) { return; }

    const repos = JSON.parse(body);

    cd(dir);

    _.each(repos, (repo) => {
        const repoDir = path.resolve(dir, repo.name);

        if (fs.existsSync(repoDir)) {
            if (args.update) {
                console.log(`${repo.name} exists, updating`);
                cd(repo.name);
                exec('git pull', { silent: true });
                cd('..');
            }
        } else {
            console.log(`Cloning ${repo.name} from Github`);
            exec(`git clone ${repo.clone_url}`, { silent: true });
        }
    });
});
